
penman.model
============

.. automodule:: penman.model

   .. autoclass:: Model

      .. automethod:: from_dict

      .. automethod:: has_role
      .. automethod:: errors

      .. automethod:: is_role_inverted
      .. automethod:: invert_role
      .. automethod:: invert
      .. automethod:: deinvert

      .. automethod:: canonicalize_role
      .. automethod:: canonicalize

      .. automethod:: is_role_reifiable
      .. automethod:: reify

      .. automethod:: is_concept_dereifiable
      .. automethod:: dereify

      .. automethod:: original_order
      .. automethod:: alphanumeric_order
      .. automethod:: canonical_order
      .. automethod:: random_order
